pdf_ocr_funtion_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-pdf-dev-lambda"
img_ocr_funtion_arn = "arn:aws:lambda:us-east-1:689835822208:function:ocr-img-dev-lambda"

base_url = "https://cjuwzz07ri.execute-api.us-east-1.amazonaws.com/prod"
# base_url = "https://api.duke.ai/api"

duke_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Duke-dev-Auto"
orchatect_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Orchatect-dev-Auto"
ralock_auto_lambda_arn = "arn:aws:lambda:us-east-1:689835822208:function:Bare-Ralock-dev-Auto"



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
                    name="dukeai",
                    version="0.1.1",
                    author="shubham kothari",
                    author_email="shubham@duke.ai",
                    description="Dukeai Development Package",
                    long_description=long_description,
                    url="https://duke.ai",
                    install_requires=['boto3', 'requests'],
                    packages=setuptools.find_packages(),
                    classifiers=[
                                    "Programming Language :: Python :: 3",
                                    "License :: OSI Approved :: MIT License",
                                    "Operating System :: OS Independent",
                                ],
                )

# pip install twine
# python setup.py sdist
# twine upload dist/*
